@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -83,7 +83,7 @@ class Engine(common.Engine):
         return self.tesseract.list_languages()
 
     @contextlib.contextmanager
-    def recognize(self, image, language, details=None):
+    def recognize(self, image, language, details=None, uax29=None):
         hocr = self._hocr
         if details is None:
             details = hocr.TEXT_DETAILS_WORD
