@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009, 2010, 2011, 2012 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ from .. import utils
 const = text_zones.const
 
 _language_pattern = re.compile('^[a-z]{3}(-[a-z]+)?$')
-_error_pattern = re.compile(r"^(Error openn?ing data|Unable to load unicharset) file (?P<dir>/.*)/[.](?P<ext>[a-z]+)\n")
+_error_pattern = re.compile(r"^(Error openn?ing data|Unable to load unicharset) file (?P<dir>/.*)/nonexistent[.](?P<ext>[a-z]+)\n")
 
 _bbox_extras_template = '''\
 <!-- The following script was appended to hOCR by ocrodjvu -->
@@ -54,7 +54,7 @@ def _wait_for_worker(worker):
         raise
     if len(stderr) == 1:
         [line] = stderr
-        if line.startswith('Tesseract Open Source OCR Engine'):
+        if line.startswith(('Tesseract Open Source OCR Engine', 'Page')):
             # Annoyingly, Tesseract prints its own name on standard error even
             # if nothing went wrong. Filter out such an unhelpful message.
             return
@@ -118,7 +118,7 @@ class Engine(common.Engine):
 
     def get_filesystem_info(self):
         try:
-            tesseract = ipc.Subprocess([self.executable, '', '', '-l', ''],
+            tesseract = ipc.Subprocess([self.executable, '', '', '-l', 'nonexistent'],
                 stdout=ipc.PIPE,
                 stderr=ipc.PIPE,
             )
@@ -163,6 +163,7 @@ class Engine(common.Engine):
         with temporary.directory() as output_dir:
             worker = ipc.Subprocess(
                 [self.executable, image.name, os.path.join(output_dir, 'tmp'), '-l', language] + self.extra_args,
+                stdout=ipc.PIPE,
                 stderr=ipc.PIPE,
             )
             _wait_for_worker(worker)
@@ -180,6 +181,7 @@ class Engine(common.Engine):
                 print >>tessconf, 'tessedit_create_hocr T'
             worker = ipc.Subprocess(
                 [self.executable, image.name, os.path.join(output_dir, 'tmp'), '-l', language, tessconf_path] + self.extra_args,
+                stdout=ipc.PIPE,
                 stderr=ipc.PIPE,
             )
             _wait_for_worker(worker)
