@@ -30,6 +30,7 @@ except ImportError, ex:
     raise
 
 from . import errors
+from . import html5_support
 from . import text_zones
 from . import unicode_support
 
@@ -87,14 +88,21 @@ bboxes_re = re.compile(
         (?: ,? \s* (?: -?\d+ \s+ -?\d+ \s+ -?\d+ \s+ -?\d+) )* )
     ''', re.VERBOSE)
 
-def _apply_bboxes(djvu_class, bbox_source, text, settings):
+def _apply_bboxes(djvu_class, bbox_source, text, settings, page_size):
     embedded_eol = False
     if djvu_class <= const.TEXT_ZONE_LINE:
         if text.endswith('\n'):
             embedded_eol = True
-    # Cuneiform tends to attach superfluous whitespace.
-    # Also, a newline character can appear at the end of line.
-    new_text = text.rstrip()
+    if settings.tesseract:
+        # Tesseract ≥ 3.00 uses space for characters it couldn't recognize
+        # (yay, excellent choice), so let's treat them just like ordinary
+        # characters. However, trailing newline characters can appear at the
+        # end of line.
+        new_text = text.rstrip('\n')
+    else:
+        # Cuneiform tends to attach superfluous whitespace.
+        # Also, a newline character can appear at the end of line.
+        new_text = text.rstrip()
     trailing_whitespace_len = len(text) - len(new_text)
     text = new_text
     del new_text
@@ -105,6 +113,10 @@ def _apply_bboxes(djvu_class, bbox_source, text, settings):
         details = TEXT_DETAILS_CHARACTER
     if details >= djvu_class:
         return [text]
+    if settings.tesseract and djvu_class >= const.TEXT_ZONE_WORD and text.isspace():
+        # Tesseract ≥ 3.0 sometimes returns series of “empty” words. Let's
+        # ignore those.
+        return []
     if isinstance(bbox_source, basestring):
         # bboxes from plain old hOCR property
         m = bboxes_re.search(bbox_source)
@@ -121,7 +133,7 @@ def _apply_bboxes(djvu_class, bbox_source, text, settings):
                     raise errors.MalformedOcrOutput('hOCR text and "makebox" output do not match')
             if upside_down < 0:
                 (x0, y0, x1, y1) = bbox
-                (w, h) = settings.page_size
+                (w, h) = page_size
                 bbox = (x0, h - y1, x1, h - y0)
             coordinates += [bbox]
     if len(coordinates) == len(text):
@@ -172,14 +184,14 @@ def _apply_bboxes(djvu_class, bbox_source, text, settings):
         ]
     return [text]
 
-def _scan(node, settings):
+def _scan(node, settings, page_size=None):
 
     def get_children(node):
         result = []
         if node.text:
             result += [node.text]
         for child in node.iterchildren():
-            result += _scan(child, settings)
+            result += _scan(child, settings, page_size)
             if child.tail:
                 result += [child.tail]
         return result
@@ -194,7 +206,11 @@ def _scan(node, settings):
         hocr_classes = (node.get('class') or '').split()
         djvu_class = None
         for hocr_class in hocr_classes:
-            djvu_class = hocr_class_to_djvu(hocr_class)
+            if settings.tesseract and hocr_class == 'ocrx_word':
+                # Tesseract > 3.00 use ocrx_word for its own purposes.
+                pass
+            else:
+                djvu_class = hocr_class_to_djvu(hocr_class)
             if djvu_class:
                 break
         else:
@@ -219,19 +235,22 @@ def _scan(node, settings):
         if not bbox:
             if settings.page_size is None:
                 raise errors.MalformedHocr("page without bounding box information")
-            page_width, page_height = settings.page_size
+            page_width, page_height = page_size = settings.page_size
             bbox = text_zones.BBox(0, 0, page_width, page_height)
         else:
             if (bbox.x0, bbox.y0) != (0, 0):
                 raise errors.MalformedHocr("page's bounding box should start with (0, 0)")
-            settings.page_size = bbox.x1, bbox.y1
+            page_size = bbox.x1, bbox.y1
+    elif page_size is None:
+        # At this point page size should be already known.
+        raise errors.MalformedHocr('unable to determine page size')
 
     has_string = has_nonempty_string = False
     has_zone = has_char_zone = has_nonchar_zone = False
     children = get_children(node)
     if len(children) == 0:
         if djvu_class is const.TEXT_ZONE_PAGE:
-            # For all other zone types, 0-child zone are simply skipped.
+            # For all other zone types, 0-child zones are simply skipped.
             # We return from the function here, to make further checks simpler.
             return [text_zones.Zone(type=djvu_class, bbox=bbox)]
         else:
@@ -257,9 +276,13 @@ def _scan(node, settings):
             raise errors.MalformedHocr("plain text intermixed with structural elements")
         if has_char_zone and has_nonchar_zone:
             raise errors.MalformedHocr("character zones intermixed with non-character zones")
-        for child in children:
-            if isinstance(child, text_zones.Zone):
-                bbox.update(child.bbox)
+        if djvu_class is const.TEXT_ZONE_PAGE:
+            # Bounding box of the whole page is not affected by its children.
+            pass
+        else:
+            for child in children:
+                if isinstance(child, text_zones.Zone):
+                    bbox.update(child.bbox)
         if len(children) == 0:
             return []
 
@@ -270,7 +293,7 @@ def _scan(node, settings):
             if not bbox:
                 raise errors.MalformedHocr("zone without bounding box information")
             text = ''.join(children)
-            children = _apply_bboxes(djvu_class, settings.bbox_data or title, text, settings)
+            children = _apply_bboxes(djvu_class, settings.bbox_data or title, text, settings, page_size)
             if len(children) == 1 and isinstance(children[0], basestring):
                 result = text_zones.Zone(type=const.TEXT_ZONE_CHARACTER, bbox=bbox, children=children)
                 # We return TEXT_ZONE_CHARACTER even it was a word according to hOCR.
@@ -291,7 +314,7 @@ def _scan(node, settings):
             if bboxes_node is not None and len(bboxes_node) == 0 and bboxes_node.text is None:
                 title = bboxes_node.get('title') or ''
         text = ''.join(children)
-        children = _apply_bboxes(djvu_class, settings.bbox_data or title, text, settings)
+        children = _apply_bboxes(djvu_class, settings.bbox_data or title, text, settings, page_size)
         if len(children) == 0:
             return []
         if isinstance(children[0], basestring):
@@ -336,15 +359,11 @@ def _scan(node, settings):
                 return []
         raise errors.MalformedHocr("text zone without bounding box information")
 
-    if settings.page_size is None:
-        # At this point page size should be already known.
-        raise errors.MalformedHocr('unable to determine page size')
-
     return [text_zones.Zone(type=djvu_class, bbox=bbox, children=children)]
 
 def scan(node, settings):
     result = []
-    for zone in _scan(node, settings):
+    for zone in _scan(node, settings, settings.page_size):
         if isinstance(zone, basestring):
             if zone == '' or zone.isspace():
                 continue
@@ -358,7 +377,7 @@ def scan(node, settings):
 
 class ExtractSettings(object):
 
-    def __init__(self, rotation=0, details=TEXT_DETAILS_WORD, uax29=None, page_size=None, cuneiform=None):
+    def __init__(self, rotation=0, details=TEXT_DETAILS_WORD, uax29=None, html5=None, page_size=None):
         self.rotation = rotation
         self.details = details
         if uax29 is not None:
@@ -368,13 +387,17 @@ class ExtractSettings(object):
             else:
                 uax29 = icu.Locale(uax29)
         self.uax29 = uax29
+        self.html5 = html5
         self.page_size = page_size
-        self.cuneiform = cuneiform
+        self.cuneiform = None
+        self.tesseract = None
         self.bbox_data = None
 
 def extract_tesseract_bbox_data(node):
     text = node.text or ''
     for line in text.splitlines():
+        if not line or line.startswith('//'):
+            continue
         ch, x0, y0, x1, y1, w = line.split()
         x0, y0, x1, y1 = map(int, (x0, y0, x1, y1))
         if ch == '~':
@@ -389,15 +412,20 @@ def extract_text(stream, **kwargs):
     uax29: None or a PyICU locale
     '''
     settings = ExtractSettings(**kwargs)
-    doc = etree.parse(stream, etree.HTMLParser())
+    if settings.html5:
+        doc = html5_support.parse(stream)
+    else:
+        doc = etree.parse(stream, etree.HTMLParser())
     if doc.find('/head/meta[@name="ocr-capabilities"]') is None:
         ocr_system = doc.find('/head/meta[@name="ocr-system"]')
-        if ocr_system is not None and ocr_system.get('content') == 'openocr':
-            settings.cuneiform = (0, 9)
-        elif ocr_system is None:
+        if ocr_system is None:
             # This is wild guess. However, since ocr-system is a required meta
             # tag, the hOCR we are processing is broken anyway.
             settings.cuneiform = (0, 8)
+        elif ocr_system.get('content') == 'openocr':
+            settings.cuneiform = (0, 9)
+        elif ocr_system.get('content') == 'tesseract':
+            settings.tesseract = True
     if settings.details < TEXT_DETAILS_WORD or (settings.uax29 and settings.details <= text_zones.TEXT_DETAILS_WORD):
         tesseract_bbox_data = doc.find('//script[@type="ocrodjvu/tesseract"]')
         if tesseract_bbox_data is not None:
