@@ -1,15 +1,18 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
+from . import utils
+
 def get_icu():
     try:
         # For PyICU ≥ 1.0
@@ -22,7 +25,7 @@ def get_icu():
         import PyICU as icu
         return icu
     except ImportError, ex:
-        ex.args = '%s; please install the PyICU package <http://pyicu.osafoundation.org/>' % str(ex),
+        utils.enhance_import_error(ex, 'PyICU', 'python-pyicu', 'http://pyicu.osafoundation.org/')
         raise
 
 def simple_word_break_iterator(text):
