@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ def _test_from_file(base_filename, index):
             assert_equal(rc, 0)
             xml_file.seek(0)
             output = xml_file.read()
-    assert_ml_equal(output, expected_output)
+    assert_ml_equal(expected_output, output)
 
 def test_from_file():
     for test_filename in sorted_glob(os.path.join(here, '*.test[0-9]')):
