@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,10 +17,17 @@ from lib.unicode_support import *
 
 text = u'\u201cJekyll,\u201d cried Utterson, with a\xa0loud voice, \u201cI demand to see you.\u201d'
 
-def test_simple_word_break_iterator():
-    t = list(simple_word_break_iterator(text))
-    s = [9, 10, 15, 16, 25, 26, 30, 31, 32, 33, 37, 38, 44, 45, 47, 48, 54, 55, 57, 58, 61, 62, 67]
-    assert_equal(t, s)
+class test_simple_word_break_iterator():
+
+    def test_nonempty(self):
+        t = list(simple_word_break_iterator(text))
+        s = [9, 10, 15, 16, 25, 26, 30, 31, 32, 33, 37, 38, 44, 45, 47, 48, 54, 55, 57, 58, 61, 62, 67]
+        assert_equal(t, s)
+        assert_equal(s[-1], len(text))
+
+    def test_empty(self):
+        t = list(simple_word_break_iterator(''))
+        assert_equal(t, [])
 
 class test_word_break_iterator():
 
@@ -28,6 +35,11 @@ class test_word_break_iterator():
         t = list(word_break_iterator(text))
         s = [9, 10, 15, 16, 25, 26, 30, 31, 32, 33, 37, 38, 44, 45, 47, 48, 54, 55, 57, 58, 61, 62, 67]
         assert_equal(t, s)
+        assert_equal(s[-1], len(text))
+
+    def test_nolocale_empty(self):
+        t = list(word_break_iterator(''))
+        assert_equal(t, [])
 
     def test_en(self):
         icu = get_icu()
@@ -35,5 +47,12 @@ class test_word_break_iterator():
         t = list(word_break_iterator(text, icu.Locale('en')))
         s = [1, 7, 8, 9, 10, 15, 16, 24, 25, 26, 30, 31, 32, 33, 37, 38, 43, 44, 45, 46, 47, 48, 54, 55, 57, 58, 61, 62, 65, 66, 67]
         assert_equal(t, s)
+        assert_equal(s[-1], len(text))
+
+    def test_en_empty(self):
+        icu = get_icu()
+        assert_not_equal(icu, None)
+        t = list(word_break_iterator('', icu.Locale('en')))
+        assert_equal(t, [])
 
 # vim:ts=4 sw=4 et
